@@ -14,51 +14,53 @@ sub grammar_file_to_yaml {
 }
 
 my $atoms = {
-    ALWAYS => '',
-    ALL => '[\s\S]',
-    ANY => '.',
-    SPACE => '[\ \t]',
-    SPACES => '\ \t',
-    BREAK => '\n',
-    EOL => '\r?\n',
-    LOWER => '[a-z]',
-    UPPER => '[A-Z]',
-    WORD => '\w',
-    DIGIT => '[0-9]',
-    WS => '\s',
+    ALWAYS  => '',
+    ALL     => '[\s\S]',
+    ANY     => '.',
+    BLANK   => '[\ \t]',
+    BLANKS  => '\ \t',
+    BREAK   => '\n',
+    EOL     => '\r?\n',
+    LOWER   => '[a-z]',
+    UPPER   => '[A-Z]',
+    DIGIT   => '[0-9]',
+    XDIGIT  => '[0-9a-fA-F]',
+    ALNUM   => '[a-zA-Z0-9]',
+    WORD    => '\w',
+    SPACE   => '\s',
 
-    SINGLE => "'",
-    DOUBLE => '"',
-    LPAREN => '\(',
-    RPAREN => '\)',
+    SINGLE  => "'",
+    DOUBLE  => '"',
+    LPAREN  => '\(',
+    RPAREN  => '\)',
     LSQUARE => '\[',
     RSQUARE => '\]',
-    LANGLE => '<',
-    RANGLE => '>',
+    LANGLE  => '<',
+    RANGLE  => '>',
 
-    BANG => '!',
-    AT => '\@',
-    HASH => '\#',
-    DOLLAR => '\$',
+    BANG    => '!',
+    AT      => '\@',
+    HASH    => '\#',
+    DOLLAR  => '\$',
     PERCENT => '%',
-    CARET => '\^',
-    AMP => '&',
-    STAR => '\*',
+    CARET   => '\^',
+    AMP     => '&',
+    STAR    => '\*',
 
-    TILDE => '~',
-    BACKTICK => '`',
-    UNDER => '_',
-    DASH => '-',
-    PLUS => '\+',
-    EQUAL => '=',
-    PIPE => '\|',
-    BACK => '\\\\',
-    COLON => ':',
-    SEMI => ';',
-    COMMA => ',',
-    DOT => '\.',
-    QUESTION => '\?',
-    SLASH => '\/',
+    TILDE   => '~',
+    GRAVE   => '`',
+    UNDER   => '_',
+    DASH    => '-',
+    PLUS    => '\+',
+    EQUAL   => '=',
+    PIPE    => '\|',
+    BACK    => '\\\\',
+    COLON   => ':',
+    SEMI    => ';',
+    COMMA   => ',',
+    DOT     => '\.',
+    QMARK   => '\?',
+    SLASH   => '\/',
 };
 
 sub compile {
